##  Use Out-of-the-Box Integrations
To explore pre-built solutions designed for integrating with third-party systems, see [Discovery and Integrations](https://help.sap.com/docs/leanix/ea/discovery-and-integrations?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how SAP LeanIX integrates with various systems, automates data syncing, enhances collaboration, and provides the reference catalog to ensure accurate and up-to-date information in your workspace.").
Advantages:
  * SAP LeanIX handles the development, operation, and maintenance of the integration.
  * A workspace administrator can configure the integration directly within the user interface of SAP LeanIX.
  * For assistance in creating a suitable configuration for your specific use case, you can refer to our extensive documentation or seek guidance from our Customer Success Team.
  * You don't need any middleware or engineering resources for the integration setup.


Disadvantages:
  * Our out-of-the-box integrations are designed for specific use cases and might not fully align with your requirements.
  * To configure some out-of-the-box integrations, you may need to purchase additional SAP LeanIX products.
  * The synchronization timing, whether real-time or based on a daily schedule, depends on the capabilities of specific integrations.
